summaryrefslogtreecommitdiffstats
path: root/lib/kross/python/pythonextension.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kross/python/pythonextension.h')
-rw-r--r--lib/kross/python/pythonextension.h54
1 files changed, 27 insertions, 27 deletions
diff --git a/lib/kross/python/pythonextension.h b/lib/kross/python/pythonextension.h
index 02e42587..b19a11a1 100644
--- a/lib/kross/python/pythonextension.h
+++ b/lib/kross/python/pythonextension.h
@@ -27,12 +27,12 @@
#include "../api/dict.h"
#include "../api/class.h"
-#include <qstring.h>
-#include <qstringlist.h>
-#include <qvaluelist.h>
-#include <qvaluevector.h>
-#include <qmap.h>
-#include <qvariant.h>
+#include <tqstring.h>
+#include <tqstringlist.h>
+#include <tqvaluelist.h>
+#include <tqvaluevector.h>
+#include <tqmap.h>
+#include <tqvariant.h>
namespace Kross { namespace Python {
@@ -135,46 +135,46 @@ namespace Kross { namespace Python {
static Kross::Api::Object::Ptr toObject(const Py::Object& object);
/**
* Converts a QString to a Py::Object. If
* the QString isNull() then Py::None() will
* be returned.
*
* \param s The QString to convert.
* \return The to a Py::String converted QString.
*/
- static const Py::Object toPyObject(const QString& s);
+ static const Py::Object toPyObject(const TQString& s);
/**
* Converts a QStringList to a Py::List.
*
* \param list The QStringList to convert.
* \return The to a Py::List converted QStringList.
*/
- static const Py::List toPyObject(const QStringList& list);
+ static const Py::List toPyObject(const TQStringList& list);
/**
* Converts a QMap to a Py::Dict.
*
* \param map The QMap to convert.
* \return The to a Py::Dict converted QMap.
*/
- static const Py::Dict toPyObject(const QMap<QString, QVariant>& map);
+ static const Py::Dict toPyObject(const TQMap<TQString, TQVariant>& map);
/**
* Converts a QValueList to a Py::List.
*
* \param list The QValueList to convert.
* \return The to a Py::List converted QValueList.
*/
- static const Py::List toPyObject(const QValueList<QVariant>& list);
+ static const Py::List toPyObject(const TQValueList<TQVariant>& list);
/**
* Converts a QVariant to a Py::Object.
*
* \param variant The QVariant to convert.
* \return The to a Py::Object converted QVariant.
*/
- static const Py::Object toPyObject(const QVariant& variant);
+ static const Py::Object toPyObject(const TQVariant& variant);
/**
* Converts a \a Kross::Api::Object to a Py::Object.
@@ -135,46 +135,46 @@ namespace Kross { namespace Python {
static Kross::Api::Object::Ptr toObject(const Py::Object& object);
/**
- * Converts a QString to a Py::Object. If
- * the QString isNull() then Py::None() will
+ * Converts a TQString to a Py::Object. If
+ * the TQString isNull() then Py::None() will
* be returned.
*
@@ -135,46 +135,46 @@ namespace Kross { namespace Python {
* be returned.
*
- * \param s The QString to convert.
- * \return The to a Py::String converted QString.
+ * \param s The TQString to convert.
+ * \return The to a Py::String converted TQString.
*/
@@ -135,46 +135,46 @@ namespace Kross { namespace Python {
/**
- * Converts a QStringList to a Py::List.
+ * Converts a TQStringList to a Py::List.
*
@@ -135,46 +135,46 @@ namespace Kross { namespace Python {
*
- * \param list The QStringList to convert.
- * \return The to a Py::List converted QStringList.
+ * \param list The TQStringList to convert.
+ * \return The to a Py::List converted TQStringList.
*/
@@ -135,46 +135,46 @@ namespace Kross { namespace Python {
/**
- * Converts a QMap to a Py::Dict.
+ * Converts a TQMap to a Py::Dict.
*
@@ -135,46 +135,46 @@ namespace Kross { namespace Python {
*
- * \param map The QMap to convert.
- * \return The to a Py::Dict converted QMap.
+ * \param map The TQMap to convert.
+ * \return The to a Py::Dict converted TQMap.
*/
@@ -135,46 +135,46 @@ namespace Kross { namespace Python {
/**
- * Converts a QValueList to a Py::List.
+ * Converts a TQValueList to a Py::List.
*
@@ -135,46 +135,46 @@ namespace Kross { namespace Python {
*
- * \param list The QValueList to convert.
- * \return The to a Py::List converted QValueList.
+ * \param list The TQValueList to convert.
+ * \return The to a Py::List converted TQValueList.
*/
@@ -135,46 +135,46 @@ namespace Kross { namespace Python {
/**
- * Converts a QVariant to a Py::Object.
+ * Converts a TQVariant to a Py::Object.
*
@@ -135,46 +135,46 @@ namespace Kross { namespace Python {
*
- * \param variant The QVariant to convert.
- * \return The to a Py::Object converted QVariant.
+ * \param variant The TQVariant to convert.
+ * \return The to a Py::Object converted TQVariant.
*/